package com.zoo.entity;

import com.fasterxml.jackson.annotation.JsonInclude;
import lombok.Data;

import java.util.Objects;

/**
 * @Author dj
 */
@JsonInclude(JsonInclude.Include.NON_NULL)
@Data
public class Result<T> {
    /**
     * 状态码
     */
    private Integer code;
    /**
     * 提示信息，如果有错误时，前端可以获取该字段进行提示
     */
    private String msg;
    /**
     * 查询到的结果数据，
     */
    private T data;

    public Result(Integer code, String msg) {
        this.code = code;
        this.msg = msg;
    }

    public Result(Integer code, T data) {
        this.code = code;
        this.data = data;
    }

    public Result(Integer code, T data,String msg) {
        this.code = code;
        this.data = data;
        this.msg = msg;
    }

    /**
     * 返回通用成功
     * @return Result
     */
    public static Result ok(){

        return new Result(20000,"请求成功");
    }


    public static Result ok(Object data,String msg){

        return new Result(20000,data,msg);
    }

    /**
     * 返回通用失败，未知错误
     * @return Result
     */
    public static Result error(){

        return new Result(20001,"请求失败");
    }

    public static Result error(String msg){

        return new Result(20001,msg);
    }

    public Integer getCode() {
        return code;
    }

    public void setCode(Integer code) {
        this.code = code;
    }

    public String getMsg() {
        return msg;
    }

    public void setMsg(String msg) {
        this.msg = msg;
    }

    public T getData() {
        return data;
    }

    public void setData(T data) {
        this.data = data;
    }

    public Result(Integer code, String msg, T data) {
        this.code = code;
        this.msg = msg;
        this.data = data;
    }
}